package Acme::MetaSyntactic::legotheincredibles;
$Acme::MetaSyntactic::legotheincredibles::VERSION = '0.02';
#ABSTRACT: LEGO The Incredibles theme

use strict;
use warnings;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();

q[You-Know-Who];

=pod

=encoding UTF-8

=head1 NAME

Acme::MetaSyntactic::legotheincredibles - LEGO The Incredibles theme

=head1 VERSION

version 0.02

=head1 DESCRIPTION

Characters from the LEGO The Incredibles game as gleaned from
the L<http://lego.wikia.com/wiki/LEGO_The_Incredibles>.

I<Jack-Jack!>

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=head1 AUTHOR

Chris Williams

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by Chris Williams.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
# names
Mr_Incredible
Elastigirl
Violet_Parr
Dash_Parr
Jack_Jack
Frozone
Anchor_Man
Anchor_Man_Goon
The_Ambassador
Ambassador_Security_Guard
Apogee
Banana_Guy
Bank_Robber
Bernie_Kropp
Blazestone
Bomb_Voyage
Bomb_Voyage_Henchman
Brainfreezer
Brainfreezer_Goon
Brainfreezer_Monster_Goon
Brick
Syndrome
Chad_Brentley
Cliffhanger
Corn_Cob_Guy
Dehydra
Diabla
Downburst
Dynaguy
Edna_Mode
Evelyn_Deavor
Everseer
Firebreak
Firefighter
Fironic
Gamma_Jack
Gazerbeam
Gilbert_Huph
Helectrix
Helicopter_Pilot
Hot_Dog_Man
Hypershock
Icebreaker
Kari_McKeen
Krushauer
Frozone
Macroburst
Meta_Man
Mirage
Municiberg_Mayor
Nomanisan_Guard
Old_Lady
Phylange
Plasmabolt
Police_Officer
Police_Sergeant
Principal_John_Walker
Psycwave
Reflux
Rick_Dicker
Robot
Russell
Rusty_McAllister
Sally_Sundae
Screech
Screenslaver
Screenslaver_Goon
Splashdown
Spot
Stormicide
Stratogale
Sulley
Syndrome
Thunderhead
Tommy
Tony_Rydinger
Tradewind
Underminer
Underminer_Goon
Universal_Man
Vectress
Voyd
WALL_E
Winston_Deavor
Woody
Zephyr
